@@ -1,28 +1,34 @@
 import improviser.Ensembles.Bands as Bands
-import improviser.Progressions.Blues as Blues
+import improviser.Progressions.Contemporary as Contemporary
 
 class Block:
 
-
-	progression = Blues.standard_blues
+	progressions = Contemporary.reincarnatie
 	
-	bpm = 220
-	iterations = 8
+	bpm = 200
 	resolution = 4
+	meter = (4,4)
 
 	swing = True
-	key = 'E'
+	key = 'A'
 	instruments = Bands.dummy
 
-	def get_bpm(self, iteration):
+	wildness = 0.7
+
+	def get_bpm(self, iterations, tick):
 		return self.bpm
 
+	def get_key(self, iteration):
+		return self.key
 
 	def get_instruments(self, iteration):
 		return self.instruments
 
+	def get_meter(self, iteration, tick):
+		return self.meter
+
 	def get_progression(self, iteration):
-		p = self.progression
+		p = self.progressions
 		res = []
 		for i in range(len(p)):
 			if i < len(p) - 1:
@@ -33,11 +39,10 @@ class Block:
 				res = p[i][1]
 				break
 		if res == 'R':
-			prog = self.progression
-			song_length = prog[-1][0] - prog[0][0]
-			for p in prog:
-				prog[prog.index(p)] = \
-					(p[0] + song_length, p[1])
+			song_length = p[-1][0] - p[0][0]
+			for prog in p:
+				p[p.index(prog)] = \
+					(prog[0] + song_length, prog[1])
 			return self.get_progression(iteration)
 		return res
 
@@ -55,4 +60,5 @@ class Block:
 				return tick_length * 0.66
 
 
-	
+	def get_wildness(self, iteration, tick):
+		return self.wildness
